/***************************************************************************
 *                                                                         *
 *  MAXIMUS-CBCS Source Code, Version 1.02                                 *
 *  Copyright 1989, 1990 by Scott J. Dudley.  All rights reserved.         *
 *                                                                         *
 *  Log-file manipulation functions                                        *
 *                                                                         *
 *  For complete details of the licensing restrictions, please refer to    *
 *  the licence agreement, which is published in its entirety in MAX.C     *
 *  and LICENCE.MAX.                                                       *
 *                                                                         *
 *  USE OF THIS FILE IS SUBJECT TO THE RESTRICTIONS CONTAINED IN THE       *
 *  MAXIMUS-CBCS LICENSING AGREEMENT.  IF YOU DO NOT FIND THE TEXT OF THIS *
 *  AGREEMENT IN ANY OF THE  AFOREMENTIONED FILES, OR IF YOU DO NOT HAVE   *
 *  THESE FILES, YOU SHOULD IMMEDIATELY CONTACT THE AUTHOR AT ONE OF THE   *
 *  ADDRESSES LISTED BELOW.  IN NO EVENT SHOULD YOU PROCEED TO USE THIS    *
 *  FILE WITHOUT HAVING ACCEPTED THE TERMS OF THE MAXIMUS-CBCS LICENSING   *
 *  AGREEMENT, OR SUCH OTHER AGREEMENT AS YOU ARE ABLE TO REACH WITH THE   *
 *  AUTHOR.                                                                *
 *                                                                         *
 *  You can contact the author at one of the address listed below:         *
 *                                                                         *
 *  Scott Dudley           FidoNet  1:249/106                              *
 *  777 Downing St.        IMEXnet  89:483/202                             *
 *  Kingston, Ont.         Internet f106.n249.z1.fidonet.org               *
 *  Canada - K7M 5N3       BBS      (613) 389-8315 - HST/14.4K, 24hrs      *
 *                                                                         *
 *  Thanks go to Peter Fitzsimmons for this module.                        *
 *                                                                         *
 ***************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <share.h>
#include <io.h>
#include <fcntl.h>
#include <stdarg.h>
#include <errno.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include "prog.h"
#include "max.h"

extern char log_name[];
extern void pascal flush_handle(FILE *fp);

static FILE *logfile=NULL;

#ifdef OS_2
#include "snserver.h"
static HSNOOP hsnoop;
static char *pipe = NULL;
#pragma check_stack(off)
static int far pascal _loadds mesgfunc(int error, char far *mesg)
{
    if(!error)
        logit(":%Fs", mesg);
    else
        logit("!SYS%04u : %Fs", error, mesg);
    return(0);
}
#pragma check_stack()
void SnSetPipeName(char *str)
{
    if(pipe)
        free(pipe);
    pipe = strdup(str);
}
#endif

static int log_written=FALSE;

int LogOpen(void)
{
  int h;

#if defined(OS_2)

  if(!pipe)
    SnSetPipeName("\\PIPE\\MaxSnoop");
  SnoopOpen(pipe, &hsnoop, xfer_id, (PFNSN)mesgfunc);

#elif defined(DESQSNOOP)

  if (do_desqsnoop)
      DesqSnoopOpen(task_num);

#endif

  if (!logfile && log_name && log_name[0])
  {
    log_written=TRUE;

    Convert_Star_To_Task(log_name);

    h=sopen(log_name,O_APPEND | O_TEXT | O_WRONLY,SH_DENYWR,S_IREAD | S_IWRITE);

    if (h==-1 && errno==ENOENT)
      h=sopen(log_name,O_TEXT | O_WRONLY | O_CREAT,SH_DENYWR,S_IREAD | S_IWRITE);

    if (h != -1)
      logfile=fdopen(h,fopen_append);

    if (!logfile)
      fprintf(stderr,s(copen_log),log_name);

    return (logfile != NULL);
  }
  else return TRUE;
}


void LogClose(void)
{
  if (logfile)
  {
    log_written=TRUE;

    LogFlush();
    fclose(logfile);
    logfile=NULL;
  }

#if defined(OS_2)

  SnoopClose(hsnoop);
  hsnoop=0;

#elif defined(DESQSNOOP)

  if (do_desqsnoop)
      DesqSnoopClose();

#endif

}


int LogWrite(char *str)
{
  int c=0;

  if (logfile)
  {
    c=fwrite(str,1,strlen(str),logfile);
    log_written=TRUE;
  }

  return c;
}

void LogFlush(void)
{
  if (logfile && log_written)
  {
    log_written=FALSE;

    fflush(logfile);
    flush_handle(logfile);
  }
}

#ifdef OS_2
void SnWrite(char *str)
{
    if(hsnoop)
        SnoopWrite(hsnoop, str);
}
#endif

